#! /bin/bash -p
#
# VMware integrated printing linux client Setup
#


print_usage() {
   printf "integrated-printing-setup.sh:\nThis script installs/uninstalls prlinuxcupsppd binary. "
   printf "Please note that you will require root provileges to execute this script.\n"

   printf "\nUsage:"
   printf "\nPass -i or --install to install prlinuxcupsppd binary for vmware integrated printing."
   printf "\nPass -u or --uninstall to uninstall prlinuxcupsppd binary.\n"
}

if [ "$#" = "0" ] ; then
   printf "No Command line options specified!\n"
   print_usage
   exit
fi

#
# Root privileges required to execute this script
#
if [ ! $EUID = "0" ]; then
   printf "Root permission required!"
   exit 1
fi

bin=/usr/bin
lib=/usr/lib

#
# install_prlinuxcupsppd():
# This function installs the prlinuxcupsppd binary
#
install_prlinuxcupsppd() {
src=$(dirname "$0")
if [ ! -f $src/prlinuxcupsppd ]; then
   printf "prlinuxcupsppd is not exist!"
   exit
fi
mkdir -p $lib/cupsPPD
cp $src/prlinuxcupsppd $lib/cupsPPD/
chmod 4755 $lib/cupsPPD/prlinuxcupsppd
ln -sf $lib/cupsPPD/prlinuxcupsppd $bin/prlinuxcupsppd
printf "prlinuxcupsppd is installed."
printf "exit."
}

#
# uninstall_prlinuxcupsppd():
# This function uninstalls the prlinuxcupsppd binary
#
uninstall_prlinuxcupsppd() {
rm $bin/prlinuxcupsppd
rm -rf $lib/cupsPPD
printf "prlinuxcupsppd is uninstalled."
printf "exit."
}


opt=$1

case $opt in
   -u|--uninstall)
      uninstall_prlinuxcupsppd
      exit
   ;;

   -i|--install)
      install_prlinuxcupsppd
      exit
   ;;
   *)
      printf "Unrecognized command line option! \n"
      print_usage
      exit
   ;;
esac