# Copyright 2020 VMware, Inc.  All rights reserved.
#
# Functions to check launching environment for Linux client
#

DISTRO=""
DISTRO_VERSION=""
STRINGS="/usr/bin/strings"

# Check the distribution version
check_distribution() {
   if [ -f /etc/os-release ] ; then
      source /etc/os-release
      DISTRO="$ID"
      DISTRO_VERSION="$VERSION_ID"

      # For Ubuntu remove "." from version
      if [ $DISTRO == "ubuntu" ] ; then
         DISTRO_VERSION="${DISTRO_VERSION//.}"
      fi

      # For RHEL don't track version after decimal
      if [ $DISTRO == "rhel" ] ; then
         DISTRO_VERSION="${DISTRO_VERSION%.*}"
      fi
   fi
}


# Check if the distribution has compatible GLIBCXX with view client
is_glibcxx_compatible_distr() {
   local result="false"
   check_distribution

   # For distribution after Ubuntu 20.04 and RHEL 8, glibcxx version is compatible
   [ $DISTRO == "ubuntu" ] && [ $DISTRO_VERSION -ge 2004 ] && result="true"
   [ $DISTRO == "rhel" ] && [ $DISTRO_VERSION -ge 8 ] && result="true"

   echo $result
}


# Check if the GLIBCXX version is compatible with view client
is_glibcxx_compatible() {
   local glibcxx=0
   local result="true"

   if [ -e $STRINGS ] || [ -h $STRINGS ] ; then
      # Use Horizon Client's libstdc++.so if GLIBCXX is below 3.4.22
      glibcxx=`/sbin/ldconfig -p | grep stdc++ | sed -e s/"^.*=> "// | xargs strings | grep GLIBCXX_3.4.22 | wc -l`
      [ $glibcxx -eq 0 ] && result="false"
   else
      result=$(is_glibcxx_compatible_distr)
   fi

   echo $result
}
